@@ -18,6 +18,7 @@ import shlex
 import shutil
 import subprocess
 import sys
+import tempfile
 import threading
 from dataclasses import dataclass, field
 from pathlib import Path
@@ -25,6 +26,8 @@ from typing import Any, Dict, Iterable, List, Optional, Sequence, Set, Tuple
 
 from loguru import logger
 from tqdm import tqdm
+from urllib.error import HTTPError, URLError
+from urllib.request import urlopen
 
 YT_CHANNEL_ID = "UC4eYXhJI4-7wSWc8UNRwD4A"
 STANDARD_OPS: Sequence[str] = (
@@ -41,6 +44,10 @@ TITLE_SUFFIX_RE = re.compile(r"([:\-\|]\s*)?\(?tiny desk.*$", re.IGNORECASE)
 YEAR_RE = re.compile(r"(\d{4})")
 ENGLISH_PREFIXES = ("en", "eng")
 SUB_LINE_RE = re.compile(r"^([A-Za-z0-9][\w\.-]*)\s")
+PLAYLIST_ORDER_CHOICES = ("shuffle", "forward", "reverse")
+CURATED_JAMLIST_URL = (
+    "https://raw.githubusercontent.com/aryakaul/tinyjam/refs/heads/main/arya-curated"
+)
 
 
 def configure_logging(verbose: bool) -> None:
@@ -158,6 +165,35 @@ def build_subtitle_args(target_language: str) -> List[str]:
     ]
 
 
+def fetch_curated_jamlist() -> Path:
+    try:
+        with urlopen(CURATED_JAMLIST_URL, timeout=30) as response:
+            payload = response.read()
+    except (HTTPError, URLError) as exc:
+        logger.error("failed to download curated jam list | {}", exc)
+        sys.exit(1)
+    except OSError as exc:
+        logger.error("network error loading curated jam list | {}", exc)
+        sys.exit(1)
+
+    if not payload:
+        logger.error("curated jam list download returned no data")
+        sys.exit(1)
+
+    try:
+        with tempfile.NamedTemporaryFile(
+            "wb", delete=False, prefix="tinyjam-curated-", suffix=".txt"
+        ) as handle:
+            handle.write(payload)
+            temp_path = Path(handle.name)
+    except OSError as exc:
+        logger.error("failed to persist curated jam list | {}", exc)
+        sys.exit(1)
+
+    logger.info("using curated jam list from {}", CURATED_JAMLIST_URL)
+    return temp_path
+
+
 @dataclass
 class TinyJamContext:
     jamlist: Path
@@ -169,6 +205,7 @@ class TinyJamContext:
     verbose: bool
     jobs: int
     subtitle_lang: str
+    playlist_order: str
     playlist: List[str] = field(default_factory=list)
     pending_downloads: List[str] = field(default_factory=list)
     download_archive: Optional[Path] = None
@@ -415,6 +452,64 @@ class TinyJam:
 
         return best_entry
 
+    def _ordered_playlist(self, items: Sequence[str]) -> List[str]:
+        order = self.ctx.playlist_order
+        if order == "forward":
+            return list(items)
+        if order == "reverse":
+            return list(reversed(items))
+        shuffled = list(items)
+        random.shuffle(shuffled)
+        return shuffled
+
+    def _video_id_from_path(self, path: str) -> Optional[str]:
+        name = Path(path).name
+        match = re.search(r"_\[([A-Za-z0-9_-]+)\]_\(", name)
+        if match:
+            return match.group(1)
+        return None
+
+    def _ordered_download_files(self, files: List[str]) -> List[str]:
+        order = self.ctx.playlist_order
+        if order == "shuffle":
+            return files
+
+        playlist = self.ctx.playlist
+        if not playlist:
+            return files if order == "forward" else list(reversed(files))
+
+        file_by_id: Dict[str, str] = {}
+        for path in files:
+            video_id = self._video_id_from_path(path)
+            if video_id:
+                file_by_id[video_id] = path
+
+        if not file_by_id:
+            return files if order == "forward" else list(reversed(files))
+
+        ordered: List[str] = []
+        referenced: Set[str] = set()
+        iterator: Iterable[str] = playlist if order == "forward" else reversed(playlist)
+
+        for artist in iterator:
+            video_id = self.ctx.cached_queries.get(artist)
+            if not video_id:
+                continue
+            file_path = file_by_id.get(video_id)
+            if not file_path:
+                continue
+            ordered.append(file_path)
+            referenced.add(file_path)
+
+        if not ordered:
+            return files if order == "forward" else list(reversed(files))
+
+        for path in files:
+            if path not in referenced:
+                ordered.append(path)
+
+        return ordered
+
     def select_video(self, artist: str) -> Optional[VideoSelection]:
         query = artist.strip()
         search_expr = f"ytsearch15:npr tiny desk {query}"
@@ -646,8 +741,7 @@ class TinyJam:
             logger.info("playlist empty | nothing to play")
             return
 
-        playlist = self.ctx.playlist[:]
-        random.shuffle(playlist)
+        playlist = self._ordered_playlist(self.ctx.playlist)
 
         color_flag = ["--saturation=20"] if self.ctx.color else ["--saturation=-100"]
         sub_flags = [
@@ -685,6 +779,9 @@ class TinyJam:
             logger.info("playback skipped | no files found in {}", self.ctx.output)
             return
 
+        ordered_files = self._ordered_download_files(files)
+        shuffle_flag = ["--shuffle"] if self.ctx.playlist_order == "shuffle" else []
+
         color_flag = ["--saturation=20"] if self.ctx.color else ["--saturation=-100"]
         sub_flags = [
             "--sub-auto=fuzzy",
@@ -696,8 +793,8 @@ class TinyJam:
             *color_flag,
             *STANDARD_OPS,
             "--loop-playlist",
-            "--shuffle",
-            *files,
+            *shuffle_flag,
+            *ordered_files,
         ]
 
         if self.ctx.dry_run:
@@ -758,7 +855,11 @@ class TinyJam:
         return 0
 
 
-def parse_args(argv: Optional[Sequence[str]] = None) -> TinyJamContext:
+def parse_args(
+    argv: Optional[Sequence[str]] = None,
+    *,
+    require_list: bool = True,
+) -> TinyJamContext:
     parser = argparse.ArgumentParser(
         description="Jam to tiny desks with tinyjam (Python edition)",
         formatter_class=argparse.ArgumentDefaultsHelpFormatter,
@@ -766,7 +867,7 @@ def parse_args(argv: Optional[Sequence[str]] = None) -> TinyJamContext:
     parser.add_argument(
         "-l",
         "--list",
-        required=True,
+        required=require_list,
         type=Path,
         help="path to artist list file (one per line)",
     )
@@ -783,6 +884,16 @@ def parse_args(argv: Optional[Sequence[str]] = None) -> TinyJamContext:
         action="store_true",
         help="stream directly from YouTube instead of downloading",
     )
+    parser.add_argument(
+        "-p",
+        "--playlist-order",
+        choices=PLAYLIST_ORDER_CHOICES,
+        default="shuffle",
+        help=(
+            "playback order: shuffle (default), jam list order (forward), "
+            "or reverse jam list order"
+        ),
+    )
     parser.add_argument(
         "-f",
         "--force",
@@ -839,13 +950,20 @@ def parse_args(argv: Optional[Sequence[str]] = None) -> TinyJamContext:
         verbose=args.verbose,
         jobs=args.jobs,
         subtitle_lang=args.subtitles,
+        playlist_order=args.playlist_order,
     )
     return ctx
 
 
 def main(argv: Optional[Sequence[str]] = None) -> int:
-    ctx = parse_args(argv)
+    args_list = list(argv) if argv is not None else sys.argv[1:]
+    use_curated_default = len(args_list) == 0
+    ctx = parse_args(args_list, require_list=not use_curated_default)
     configure_logging(ctx.verbose)
+    if use_curated_default:
+        ctx.jamlist = fetch_curated_jamlist()
+        ctx.nodownload = True
+        logger.info("no options provided | defaulting to streaming mode")
     app = TinyJam(ctx)
     return app.run()
 
